@@ -20,7 +20,6 @@ def get_settings_at_path(dot_path):
     current = yaml_dict
     for chunk in dot_path.split('.'):
         current = current[chunk]
-    merge_cluster(current)
     return current
 
 def default_client():
@@ -30,7 +29,7 @@ def default_client():
     Returns:
         A dictionary containing the default client settings.
     """
-    return get_client(read_config_file()['defaults']['default_client'])
+    return get_settings(read_config_file()['defaults']['default_client'])
 
 def unittest_client():
     """
@@ -39,7 +38,7 @@ def unittest_client():
     Returns:
         A dictionary containing the default client settings.
     """
-    return get_client(read_config_file()['defaults']['unittest_client'])
+    return get_settings(read_config_file()['defaults']['unittest_client'])
 
 def client(client_name):
     """ DEPRECATED """
@@ -56,7 +55,6 @@ def get_client(client_name):
         A dictionary containing the client settings.
     """
     client = get_settings_at_path("clients." + client_name)
-    merge_cluster(client)
 
     return client
 
@@ -77,6 +75,24 @@ def get_cluster(cluster_name):
     """
     return get_settings_at_path("clusters." + cluster_name)
 
+def get_settings(key):
+    """
+    Get the settings defined for the specified client or cluster.
+
+    Args:
+        key - The name of the client or cluster defined in the config file
+
+    Returns:
+        A dictionary containing the specified settings.
+    """
+    try:
+        return get_settings_at_path(key)
+    except JanrainConfigError:
+        try:
+            return get_settings_at_path("clients." + key)
+        except JanrainConfigError:
+            return get_settings_at_path("clusters." + key)
+
 def get_clusters():
     """
     Get the list of all clusters.
@@ -98,17 +114,6 @@ def get_config_file():
     except KeyError:
         return os.path.join(os.path.expanduser("~"), ".janrain-capture")
 
-def merge_cluster(settings):
-    """
-    Merge the cluster settings into the dictionary if a 'clusters' key exists.
-
-    Args:
-        settings - The settings to dictionary to merge cluster setings into.
-    """
-    if 'cluster' in settings:
-        # merge in cluster values
-        settings.update(get_cluster(settings['cluster']))
-
 def read_config_file():
     """
     Parse the YAML configuration file into Python types.
@@ -119,7 +124,14 @@ def read_config_file():
     file = get_config_file()
     with open(file) as stream:
         yaml_dict = yaml.load(stream.read())
-    return ConfigDict(file, yaml_dict)
+    config = ConfigDict(file, yaml_dict)
+    # merge clusters into clients
+    if 'clusters' in config and 'clients' in config:
+        for client in config['clients'].itervalues():
+            if 'cluster' in client:
+                for key, value in config['clusters'][client['cluster']].iteritems():
+                    client.setdefault(key, value)
+    return config
 
 from collections import MutableMapping
 
@@ -157,3 +169,19 @@ class ConfigDict(MutableMapping):
 
     def get_key_path(self, key):
         return self.root + '.' + key if self.root else key
+
+    def __str__(self):
+        pairs = []
+        for key, value in self.values.iteritems():
+            if isinstance(value, ConfigDict):
+                value = str(value)
+            else:
+                value = repr(value)
+            pairs.append("{key}: {value}".format(key=repr(key), value=value))
+        return "{{{0}}}".format(", ".join(pairs))
+
+    def __repr__(self):
+        if self.root:
+            return repr(self.values)
+        else:
+            return "ConfigDict{}".format(repr((self.file, self.values)))
